# Generated by Django 2.1.1 on 2018-09-16 14:20

import django.contrib.postgres.fields.jsonb
import django.contrib.postgres.indexes
from django.contrib.postgres.operations import BtreeGinExtension
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        BtreeGinExtension(),
        migrations.CreateModel(
            name='Task',
            fields=[
                ('id', models.CharField(help_text='Task ID', max_length=512, primary_key=True, serialize=False)),
                ('first_saved', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('data', django.contrib.postgres.fields.jsonb.JSONField(blank=True, help_text='Task data')),
            ],
        ),
        migrations.AddIndex(
            model_name='task',
            index=django.contrib.postgres.indexes.GinIndex(fields=['data'], name='celery_pant_data_785c1b_gin'),
        ),
    ]
